@@ -57,6 +57,9 @@ standardizeInput <- function(obj, v) {
 #' will be randomized.
 #' @param alpha numeric between 0 and 1 specifying the fraction on how much keys containing \code{NAs} should
 #' contribute to the frequency calculation which is also crucial for risk-estimation.
+#' @references Templ, M. and Meindl, B. and Kowarik, A.: \emph{Statistical Disclosure Control for
+#' Micro-Data Using the R Package sdcMicro}, Journal of Statistical Software,
+#' 67 (4), 1--36, 2015. \doi{10.18637/jss.v067.i04}
 #' @export
 #' @examples
 #' ## we can also specify ghost (linked) variables
@@ -82,7 +85,9 @@ standardizeInput <- function(obj, v) {
 #' ghostVars[[1]] <- list()
 #' ghostVars[[1]][[1]] <- "electcon"
 #' ghostVars[[1]][[2]] <- c("electcon2","electcon3")
-#'
+#' 
+#' \dontrun{
+#' # dontrun because Examples with CPU time > 2.5 times elapsed time
 #' ## we want variable 'water2' to be linked to key-variable 'water'
 #' ghostVars[[2]] <- list()
 #' ghostVars[[2]][[1]] <- "water"
@@ -106,6 +111,7 @@ standardizeInput <- function(obj, v) {
 #' obj <- createSdcObj(testdata, keyVars=c("urbrur","roof","walls"), numVars="savings",
 #'    weightVar=w, excludeVars=c("relat","electcon","hhcivil","ori_hid","expend"))
 #' colnames(get.sdcMicroObj(obj, "origData"))
+#' }
 createSdcObj <- function(dat, keyVars, numVars=NULL, pramVars=NULL, ghostVars=NULL, weightVar=NULL,
   hhId=NULL, strataVar=NULL, sensibleVar=NULL, excludeVars=NULL, options=NULL, seed=NULL,
   randomizeRecords=FALSE, alpha=1) {
@@ -134,8 +140,8 @@ createSdcObj <- function(dat, keyVars, numVars=NULL, pramVars=NULL, ghostVars=NU
     standardizeInput(obj, numVars), standardizeInput(obj, pramVars),
     standardizeInput(obj, weightVar), standardizeInput(obj, hhId),
     standardizeInput(obj, strataVar), standardizeInput(obj, sensibleVar))
-  if (!is.null(ghostVars )) {
-    for ( i in seq_along(ghostVars)) {
+  if (!is.null(ghostVars)) {
+    for (i in seq_along(ghostVars)) {
       usedVars <- c(usedVars, standardizeInput(obj, ghostVars[[i]][[2]]))
     }
   }
@@ -143,7 +149,7 @@ createSdcObj <- function(dat, keyVars, numVars=NULL, pramVars=NULL, ghostVars=NU
   # exclude variables if required
   if (!is.null(excludeVars)) {
     excludeVarsInd <- standardizeInput(obj, excludeVars)
-    if ( any(excludeVarsInd %in% usedVars) ) {
+    if (any(excludeVarsInd %in% usedVars)) {
       stop("You have specified variables in 'excludeVars' that cannot be removed!\n")
     }
     obj@origData <- obj@origData[,-c(excludeVarsInd),drop=FALSE]
@@ -406,6 +412,7 @@ setMethod(f="extractManipDataX", signature=c("sdcMicroObj"), definition=function
   n <- get.sdcMicroObj(obj, type="manipNumVars")
   g <- get.sdcMicroObj(obj, type="manipGhostVars")
   s <- get.sdcMicroObj(obj, type="manipStrataVar")
+  origKeys <- o[,colnames(k)]
   if (!is.null(k) && !ignoreKeyVars)
     o[, colnames(k)] <- k
   if (!is.null(p) && !ignorePramVars)
@@ -419,7 +426,22 @@ setMethod(f="extractManipDataX", signature=c("sdcMicroObj"), definition=function
   ## quick and dirty: ensure that keyVars are factors:
   if (!is.null(k) && !ignoreKeyVars) {
     for (i in 1:length(colnames(k))) {
-      o[, colnames(k)[i]] <- as.factor(o[, colnames(k)[i]])
+      cc <- class(origKeys[, colnames(k)[i]])
+      v_p <- o[,colnames(k)[i]]
+      if (cc!=class(v_p)) {
+        if (cc=="integer") {
+          o[,colnames(k)[i]] <- as.integer(v_p)
+        }
+        if (cc=="character") {
+          o[,colnames(k)[i]] <- as.character(v_p)
+        }
+        if (cc=="numeric") {
+          o[,colnames(k)[i]] <- as.numeric(v_p)
+        }
+        if (cc=="logical") {
+          o[,colnames(k)[i]] <- as.logical(v_p)
+        }
+      }
     }
   }
 
