@@ -81,6 +81,7 @@
 #' \item{\code{aggr}: }{aggregation level}
 #' \item{\code{measure}: }{proximity measure for aggregation}}
 #' @note if only one variable is specified, \code{\link{mafast}} is applied and argument \code{method} is ignored.
+#' Parameters \code{measure} are ignored for methods \code{mdav} and \code{rmd}.
 #' @author Matthias Templ, Bernhard Meindl
 #'
 #' For method \dQuote{mdav}: This work is being supported by the International
@@ -107,6 +108,10 @@
 #' Imputation: Robust Statistics Applied to Official Statistics},
 #' Suedwestdeutscher Verlag fuer Hochschulschriften, 2009, ISBN: 3838108280,
 #' 264 pages.
+#' 
+#' Templ, M. Statistical Disclosure Control for Microdata: Methods and Applications in R.
+#' \emph{Springer International Publishing}, 287 pages, 2017. ISBN 978-3-319-50272-4. \doi{10.1007/978-3-319-50272-4}
+#' \doi{10.1007/978-3-319-50272-4}
 #'
 #' Templ, M. and Meindl, B. and Kowarik, A.: \emph{Statistical Disclosure Control for
 #' Micro-Data Using the R Package sdcMicro}, Journal of Statistical Software,
@@ -138,6 +143,10 @@
 microaggregation <- function(obj, variables=NULL, aggr=3, strata_variables=NULL,
   method="mdav", weights=NULL, nc=8, clustermethod="clara",
   measure="mean", trim=0, varsort=1, transf="log") {
+
+  if (!is.data.frame(obj) & !is.null(strata_variables)) {
+    message("Argument 'strata_variables' is ignored. Only variables specified in slot 'strataVar' (if any) of the input object are used!\n")
+  }
   microaggregationX(obj=obj, variables=variables, aggr=aggr, strata_variables=strata_variables,
     method=method, weights=weights, nc=nc, clustermethod=clustermethod,
     measure=measure, trim=trim, varsort=varsort, transf=transf)
